@@ -8,6 +8,8 @@
  */
 class EffectReverse : public ViewEffect {
     public:
+        static const char *NAME;
+        virtual const char* getName() const { return NAME; }
         virtual void blit(SDL_Surface *screen, SDL_Surface *surface,
                 int x, int y);
 };
