@@ -10,6 +10,8 @@ class SurfaceTool {
     public:
         static SDL_Surface *createEmpty(SDL_Surface *surface,
                 int width=0, int height=0);
+        static SDL_Surface *createTransparent(int w, int h,
+                const SDL_Color &transparent);
         static SDL_Surface *createClone(SDL_Surface *surface);
         static void alphaFill(SDL_Surface *surface, SDL_Rect *dstrect,
                 const SDL_Color &color);
