@@ -25,6 +25,12 @@ BaseListener::registerWatcher(const std::string &param)
     StringMsg *event = new StringMsg(this, "param_changed", param);
     OptionAgent::agent()->addWatcher(param, event);
 }
+//-----------------------------------------------------------------
+    void
+BaseListener::removeWatchers()
+{
+    OptionAgent::agent()->removeWatchers(getName());
+}
 //-----------------------------------------------------------------
 /**
  * @throws UnknownMsgException
