@@ -12,16 +12,16 @@ class Dialog;
  * Multi-language dialogs pack.
  */
 class ResDialogPack : public ResourcePack<Dialog*> {
-    protected:
-        virtual void unloadRes(Dialog *res);
+    private:
         int matchScore(const std::string &first,
                 const std::string &second) const;
-    public:
-        virtual const char *getName() const { return "dialog_pack"; }
         const Dialog *findDialog(const std::string &name,
                 const std::string &lang);
-        const Dialog *findDialogHard(const std::string &name,
-                const std::string &select="lang");
+    public:
+        virtual const char *getName() const { return "dialog_pack"; }
+        const Dialog *findDialogHard(const std::string &name);
+        const Dialog *findDialogSpeech(const std::string &name);
+        virtual void unloadRes(Dialog *res);
 };
 
 #endif
