@@ -27,7 +27,7 @@ ResSoundPack::loadSound(const Path &file)
 {
     Mix_Chunk *chunk = NULL;
     //TODO: ask SoundAgent to load this sound
-    if (OptionAgent::agent()->getAsInt("sound", 1)) {
+    if (OptionAgent::agent()->getAsBool("sound", true)) {
         chunk = Mix_LoadWAV(file.getNative().c_str());
         if (NULL == chunk) {
             LOG_WARNING(ExInfo("cannot load sound")
