@@ -42,7 +42,8 @@ class Level : public GameState, public CountAdvisor {
         LevelCountDown *m_countdown;
         CommandQueue *m_show;
         int m_restartCounter;
-        bool m_insideUndo;
+        int m_undoSteps;
+        bool m_wasDangerousMove;
         MultiDrawer *m_background;
         StatusDisplay *m_statusDisplay;
     private:
@@ -53,9 +54,11 @@ class Level : public GameState, public CountAdvisor {
         void finishLevel();
         void nextLoadAction();
         void nextShowAction();
+        void nextUndoAction();
         void nextPlayerAction();
         void saveSolution();
         void displaySaveStatus();
+        bool isUndoing() const;
     protected:
         virtual void own_initState();
         virtual void own_updateState();
@@ -75,11 +78,12 @@ class Level : public GameState, public CountAdvisor {
         void loadGame(const std::string &moves);
         void loadReplay(const std::string &moves);
 
-        bool action_restart();
+        bool action_restart(int increment);
         bool action_move(char symbol);
         bool action_save();
         bool action_load();
-        bool action_undo();
+        void action_undo(int steps);
+        void action_undo_finish();
 
         void switchFish();
         void controlEvent(const KeyStroke &stroke);
@@ -90,9 +94,10 @@ class Level : public GameState, public CountAdvisor {
         int getDepth() const { return m_depth; }
         bool isNewRound() const { return m_newRound; }
 
-        void createRoom(int w, int h, const Path &picture);
+        void createRoom(int w, int h, const std::string &picture);
         void newDemo(const Path &demofile);
 
+        bool isActing() const;
         bool isLoading() const;
         void togglePause();
         bool isShowing() const;
