@@ -34,6 +34,11 @@ LevelInput::LevelInput(Level *level)
     KeyDesc undo = KeyDesc(KEY_UNDO, "undo");
     m_keymap->registerKey(KeyStroke(SDLK_MINUS, KMOD_NONE), undo);
     m_keymap->registerKey(KeyStroke(SDLK_KP_MINUS, KMOD_NONE), undo);
+
+    KeyDesc redo = KeyDesc(KEY_REDO, "redo");
+    m_keymap->registerKey(KeyStroke(SDLK_PLUS, KMOD_NONE), redo);
+    m_keymap->registerKey(KeyStroke(SDLK_EQUALS, KMOD_NONE), redo);
+    m_keymap->registerKey(KeyStroke(SDLK_KP_PLUS, KMOD_NONE), redo);
 }
 //-----------------------------------------------------------------
 Level *
@@ -47,26 +52,33 @@ LevelInput::specKey(int keyIndex)
 {
     switch (keyIndex) {
         case KEY_SWITCH:
-            if (!getLevel()->isShowing() && !getLevel()->isLoading()) {
+            if (!getLevel()->isActing()) {
                 getLevel()->switchFish();
             }
             break;
         case KEY_SAVE:
-            if (!getLevel()->isShowing() && !getLevel()->isLoading()) {
+            if (!getLevel()->isActing()) {
                 getLevel()->action_save();
             }
             break;
         case KEY_LOAD:
-            getLevel()->interruptShow();
-            getLevel()->action_load();
+            if (!getLevel()->isShowing()) {
+                getLevel()->action_load();
+            }
             break;
         case KEY_RESTART:
             getLevel()->interruptShow();
-            getLevel()->action_restart();
+            getLevel()->action_restart(1);
             break;
         case KEY_UNDO:
-            getLevel()->interruptShow();
-            getLevel()->action_undo();
+            if (!getLevel()->isShowing()) {
+                getLevel()->action_undo(1);
+            }
+            break;
+        case KEY_REDO:
+            if (!getLevel()->isShowing()) {
+                getLevel()->action_undo(-1);
+            }
             break;
         case KEY_SHOW_STEPS:
             toggleParam("show_steps");
@@ -79,7 +91,7 @@ LevelInput::specKey(int keyIndex)
 void
 LevelInput::specStroke(const KeyStroke &stroke)
 {
-    if (!getLevel()->isShowing() && !getLevel()->isLoading()) {
+    if (!getLevel()->isActing()) {
         getLevel()->controlEvent(stroke);
     }
 }
@@ -89,4 +101,17 @@ LevelInput::mouseEvent(const MouseStroke &buttons)
 {
     getLevel()->controlMouse(buttons);
 }
+//-----------------------------------------------------------------
+void
+LevelInput::keyUp(const KeyStroke &stroke) {
+    int index = m_keymap->indexPressed(stroke);
+    switch (index) {
+        case KEY_UNDO:
+        case KEY_REDO:
+            getLevel()->action_undo_finish();
+            break;
+        default:
+            break;
+    }
+}
 
