@@ -79,6 +79,8 @@ Rules::takeField(Field *field)
  * Accomplish last move in m_dir direction.
  * Mask to a new position.
  * Change model position.
+ *
+ * It complements the unmasking in freeOldPos().
  */
     void
 Rules::occupyNewPos()
@@ -310,15 +312,6 @@ Rules::clearLastFall()
     return last;
 }
 //-----------------------------------------------------------------
-/**
- * Unmask from old position.
- */
-    void
-Rules::finishRound()
-{
-    freeOldPos();
-}
-//-----------------------------------------------------------------
 /**
  * Unmask from old position.
  */
