@@ -236,6 +236,12 @@ Unit::isMoving() const
 }
 //-----------------------------------------------------------------
 bool
+Unit::isMovingDown() const
+{
+    return m_model->rules()->getDir() == Dir::DIR_DOWN;
+}
+//-----------------------------------------------------------------
+bool
 Unit::isTurning() const
 {
     std::string action = m_model->rules()->getAction();
@@ -245,7 +251,16 @@ Unit::isTurning() const
 bool
 Unit::isPushing() const
 {
-    return m_model->rules()->getState() == "pushing";
+    return m_model->rules()->isPushing();
+}
+//-----------------------------------------------------------------
+bool
+Unit::isDrivenBy(char symbol) const
+{
+    return m_symbols.getLeft() == symbol
+        || m_symbols.getRight() == symbol
+        || m_symbols.getUp() == symbol
+        || m_symbols.getDown() == symbol;
 }
 //-----------------------------------------------------------------
 /**
