@@ -20,12 +20,7 @@
 #include "ModelFactory.h"
 #include "Room.h"
 #include "RopeDecor.h"
-
-#include "EffectNone.h"
-#include "EffectMirror.h"
-#include "EffectInvisible.h"
-#include "EffectReverse.h"
-#include "EffectZx.h"
+#include "ShapeBuilder.h"
 
 #include "def-script.h"
 
@@ -159,11 +154,25 @@ script_game_changeBg(lua_State *L) throw()
 {
     BEGIN_NOEXCEPTION;
     const char *picture = luaL_checkstring(L, 1);
-    getLevelScript(L)->room()->changeBg(Path::dataReadPath(picture));
+    getLevelScript(L)->room()->changeBg(picture);
     END_NOEXCEPTION;
     return 0;
 }
 //-----------------------------------------------------------------
+/**
+ * string game_getBg()
+ * Return the name of the currently used bg picture.
+ */
+    int
+script_game_getBg(lua_State *L) throw()
+{
+    BEGIN_NOEXCEPTION;
+    lua_pushstring(L, getLevelScript(L)->room()->getBg().c_str());
+    END_NOEXCEPTION;
+    //NOTE: return bg
+    return 1;
+}
+//-----------------------------------------------------------------
 /**
  * void game_checkActive()
  * Check active fish, switch to non busy alive fish.
@@ -209,7 +218,13 @@ script_model_addAnim(lua_State *L) throw()
             luaL_optint(L, 4, Anim::SIDE_LEFT));
 
     Cube *model = getModel(L, model_index);
-    model->anim()->addAnim(anim_name, Path::dataReadPath(picture), lookDir);
+    if (picture[0] == '\0') {
+        model->anim()->addAnim(anim_name,
+                ShapeBuilder::createImage(model->shape(), model->getWeight()),
+                lookDir);
+    } else {
+        model->anim()->addAnim(anim_name, Path::dataReadPath(picture), lookDir);
+    }
     END_NOEXCEPTION;
     return 0;
 }
@@ -296,30 +311,10 @@ script_model_setEffect(lua_State *L) throw()
 {
     BEGIN_NOEXCEPTION;
     int model_index = luaL_checkint(L, 1);
-    std::string effect_name = luaL_checkstring(L, 2);
-
+    std::string effectName = luaL_checkstring(L, 2);
     Cube *model = getModel(L, model_index);
-    if ("none" == effect_name) {
-        model->anim()->changeEffect(new EffectNone());
-    }
-    else if ("mirror" == effect_name) {
-        model->anim()->changeEffect(new EffectMirror());
-    }
-    else if ("invisible" == effect_name) {
-        model->anim()->changeEffect(new EffectInvisible());
-    }
-    else if ("reverse" == effect_name) {
-        model->anim()->changeEffect(new EffectReverse());
-    }
-    else if ("zx" == effect_name) {
-        model->anim()->changeEffect(new EffectZx());
-    }
-    else {
-        ExInfo error = ExInfo("unknown view effect")
-            .addInfo("effect", effect_name);
-        LOG_WARNING(error);
-        luaL_error(L, error.what());
-    }
+    model->anim()->setEffect(effectName);
+
     END_NOEXCEPTION;
     return 0;
 }
@@ -665,23 +660,22 @@ script_model_getExtraParams(lua_State *L) throw()
     int model_index = luaL_checkint(L, 1);
     Cube *model = getModel(L, model_index);
 
-    if (model->getOutCapacity() != 0) {
-        lua_newtable(L);
-        lua_pushstring(L, "outDir");
-        lua_pushnumber(L, model->getOutDir());
-        lua_settable(L, -3);
+    lua_newtable(L);
+    lua_pushstring(L, "outDir");
+    lua_pushnumber(L, model->getOutDir());
+    lua_settable(L, -3);
 
-        lua_pushstring(L, "outCapacity");
-        lua_pushnumber(L, model->getOutCapacity());
-        lua_settable(L, -3);
+    lua_pushstring(L, "outCapacity");
+    lua_pushnumber(L, model->getOutCapacity());
+    lua_settable(L, -3);
 
-        lua_pushstring(L, "weight");
-        lua_pushnumber(L, model->getWeight());
-        lua_settable(L, -3);
-    }
-    else {
-        lua_pushnil(L);
-    }
+    lua_pushstring(L, "weight");
+    lua_pushnumber(L, model->getWeight());
+    lua_settable(L, -3);
+
+    lua_pushstring(L, "anim");
+    lua_pushstring(L, model->anim()->getState().c_str());
+    lua_settable(L, -3);
 
     END_NOEXCEPTION;
     return 1;
@@ -698,22 +692,26 @@ script_model_change_setExtraParams(lua_State *L) throw()
     BEGIN_NOEXCEPTION;
     int model_index = luaL_checkint(L, 1);
 
-    if (!lua_isnil(L, 2)) {
-        lua_pushstring(L, "outDir");
-        lua_gettable(L, 2);
-        int outDir = luaL_checkint(L, -1);
+    lua_pushstring(L, "outDir");
+    lua_gettable(L, 2);
+    int outDir = luaL_checkint(L, -1);
 
-        lua_pushstring(L, "outCapacity");
-        lua_gettable(L, 2);
-        int outCapacity = luaL_checkint(L, -1);
+    lua_pushstring(L, "outCapacity");
+    lua_gettable(L, 2);
+    int outCapacity = luaL_checkint(L, -1);
 
-        lua_pushstring(L, "weight");
-        lua_gettable(L, 2);
-        int weight = luaL_checkint(L, -1);
+    lua_pushstring(L, "weight");
+    lua_gettable(L, 2);
+    int weight = luaL_checkint(L, -1);
 
-        Cube *model = getModel(L, model_index);
-        model->setOutDir((Dir::eDir)outDir, outCapacity, (Cube::eWeight)weight);
-    }
+    lua_pushstring(L, "anim");
+    lua_gettable(L, 2);
+    std::string animState = luaL_checkstring(L, -1);
+
+    Cube *model = getModel(L, model_index);
+    model->setOutDir((Dir::eDir)outDir, outCapacity, (Cube::eWeight)weight);
+    model->setExtraParams();
+    model->anim()->restoreState(animState);
 
     END_NOEXCEPTION;
     return 0;
